# Management Network User Guide

This documentation helps network administrators and support personnel install install and manage Aruba, Dell, and Mellanox network devices in a CSM install.

The HPE Cray recommended way of configuring the network is by using the CANU tool. Therefore this guide will not go into detail on how to configure each
switch manually using the CLI. Instead, it will give helpful examples of how to configure/use features generated by CANU, in order to provide administrators
easy ways to customize their installation.

Also included in this guide are the current documented and supported network scenarios.

**`NOTE`** Not every configuration option is covered here; for any configuration outside of the scope of this document, refer to the official
Aruba, Dell, or Mellanox user manuals.

This document is intended for network administrators and support personnel.

**`NOTE`** The display and command lines illustrated in this document are examples and might not exactly match any particular environment. The switch and
accessory drawings in this document are for illustration only, and may not exactly match installed products.

## Contents

- [Switch configuration states](#switch-configuration-states)
- [Starting points](#starting-points)
- [Platform-specific user guides](#platform-specific-user-guides)
- [CANU](#canu)
- [Useful pages](#useful-pages)
- [Products supported](#products-supported)
- [Architecture and naming conventions](#architecture-and-naming-conventions)
- [Minimum software version requirements](#minimum-software-version-requirements)
- [Changes](#changes)
  - [Enhancements](#enhancements)
    - [Spanning-tree](#spanning-tree)
  - [Fixes](#fixes)
  - [Issues and workarounds](#issues-and-workarounds)
  - [Security Bulletin subscription service](#security-bulletin-subscription-service)

## Switch configuration states

To check the current state of the switches, see [Upgrade](upgrade.md).

- `1.0 Config`: Non-CANU-generated switch configurations
- `1.2 Preconfig`: CANU-generated configurations for CSM 1.0
- `1.2 Config`: CANU-generated configurations for CSM 1.2

## Starting points

| Situation                                                                       | Link                                              |
| ------------------------------------------------------------------------------- | ------------------------------------------------- |
| Upgrade CANU to the latest version                                              | [Install/Upgrade CANU](canu_install_update.md)    |
| Upgrade to CANU-generated configurations from non-CANU-generated configurations | [Upgrade](upgrade.md)                             |
| Current switch configurations are CANU-generated and need to go to 1.3          | [`1.3 (Preconfig)` to 1.3](1.2_to_1.3_upgrade.md) |
| Switches have no configuration on them                                          | [Fresh Install](fresh_install.md)                 |
| Reinstalling the same CSM version                                               | [Re-install](reinstall.md)                        |
| New hardware was added to the system                                            | [Added Hardware](added_hardware.md)               |
| Switch failed and needs to be replaced                                          | [Replace Switch](replace_switch.md)               |

## Platform-specific user guides

The user guides contain information such as generic configuration examples, explanation of currently used technologies, topology maps, and a
summary of the network design used in the CSM management network.

- [Aruba](aruba/README.md)
- [Dell](dell/README.md)
- [Mellanox](mellanox/README.md)

## CANU

See [CSM Automatic Network Utility (CANU)](canu/README.md).

## Useful pages

| Page                                                                                 | Description                                                                 |
| ------------------------------------------------------------------------------------ | --------------------------------------------------------------------------- |
| [Collect data](collect_data.md)                                                      | Input data needed to generate switch configurations                         |
| [Cable Management Network Servers](cable_management_network_servers.md)              | Shows how servers in CSM should be cabled                                   |
| [SHCD HMN Tab/HMN Connections Rules](../../../install/shcd_hmn_connections_rules.md) | Shows how the HMN tab on the SHCD should be formatted                       |
| [Backup Custom Configurations](backup_custom_configurations.md)                      | Shows users how to backup configurations that are custom to their system; this includes site connections and credentials |
| [Configuration Management](config_management.md)                                     | Shows users how to save a running configuration to the switch for backup purposes, or to switch between different switch configurations |
| [Validate Switch Configuration](validate_switch_configs.md)                          | Compares the configuration on a running system to what is generated by CANU |
| [Wipe Management Switches](wipe_mgmt_switches.md)                                    | Erase the switch configuration; this is useful for fresh installs           |
| [Generate Switch Configurations](generate_switch_configs.md)                         | Generate configurations for all management switches                         |
| [Manual Switch Configurations](manual_switch_config.md)                              | Some configuration needs to be done manually (authentication/SNMP)          |
| [Validate SHCD](validate_shcd.md)                                                    | Validate the SHCD against the CSM network architecture                      |

## Products supported

This release applies to the following product models:

- Aruba `8320` switch series
- Aruba `8325` switch series
- Aruba `8360` switch series
- Aruba `6300` switch series
- Mellanox `SN2100` switch series
- Mellanox `SN2700` switch series
- Dell `S3048-ON` switch series
- Dell `S4148T-ON` switch series
- Dell `S4148F-ON` switch series

## Architecture and naming conventions

For architecture and naming convention information, see
[Cray Network Architecture model](https://github.com/Cray-HPE/canu/blob/main/network_modeling/models/cray-network-architecture.yaml).

## Minimum software version requirements

See [Network Firmware](firmware/update_management_network_firmware.md).

## Changes

These sections list enhancements, fixes, and known issues for this version of the Shasta management network.

- [Enhancements](#enhancements)
  - [Spanning-tree](#spanning-tree)
- [Fixes](#fixes)
- [Issues and workarounds](#issues-and-workarounds)
- [Security Bulletin subscription service](#security-bulletin-subscription-service)

### Enhancements

Software enhancements are listed in reverse-chronological order, with the newest on the top of the list.

Unless otherwise noted, each network version listed includes all enhancements added in earlier versions.

#### Spanning-tree

In the Shasta management network version 1.2, Spanning-tree configuration is changing from RPVST (RSTP) to
MSTP, in order to allow for better vendor interoperability and simplified Spanning-tree configuration. The
new default configuration is as follows:

- Spanning-tree BPDU guard is removed from NCN LAG ports.
- Spanning-tree BPDU filter is removed.
- Spanning-tree admin-edge port settings are retained for allowing quicker PXE boot.
- Spanning-tree instance is tied to default (no longer multiple instances or per VLAN).
- Spanning-tree MSTP configuration name and revision in all configurations generated by CANU are set.
- Add peering from MetalLB to customer edge router.

### Fixes

### Issues and workarounds

The following are known open issues with this branch of the software.

The Symptom statement describes what a user might experience if this is seen on the network. The Scenario statement provides additional environment details and trigger summaries.
When available, the Workaround statement provides a workaround to the issue.

> Known and fixed issue are listed in the CANU release notes.
See [CANU releases](https://github.com/Cray-HPE/canu/releases).

### Security Bulletin subscription service

To initiate a subscription to receive future HPE Security Bulletin alerts via email,
see the [`HPE Support Center`](https://support.hpe.com/connect/s/?language=en_US).

A Security Bulletin is the published notification of security vulnerabilities and is the only communication
vehicle for security vulnerabilities.

- Fixes for security vulnerabilities are not documented in manuals, release notes, or other forms of product
documentation.
- A Security Bulletin is released when all vulnerable products still in support life have publicly available
images that contain the fix for the security vulnerability.
